==> fantacalciobazar_0.5.1.tar.gz: fantacalciobazar/guarda_giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


$parla = "NO";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");


for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_controlla = "giornata$num1";
if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
else $giornata_ultima = $num1;
} # fine for $num1

$num_giornata_richiesta = substr($giornata,-2);
if (!$giornata or $num_giornata_richiesta > $giornata_ultima) $giornata = "giornata$giornata_ultima";

echo "<table width=\"100%\" align=\"center\"><tr><td width=\"33%\" align=\"left\">
<form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 <= $giornata_ultima ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine for $num1
echo "</select></form></td>";

echo "<td align=\"center\"><center><b>$giornata</b></center></td>
<td width=\"33%\" align=\"right\">
<form method=\"post\" action=\"calendario.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Calendario\">
</form></td></tr></table>";
$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";
$voti = "";
$scontri = "";
$num2 = 0;
$leggendo_formazioni = "SI";
$leggendo_punteggi = "NO";
$leggendo_voti = "NO";
$leggendo_scontri = "NO";
$voti_esistenti = "NO";

if ($giornata_ultima) $file_giornata = file("$percorso_cartella_dati/$giornata");
$num_linee_file_giornata = count($file_giornata);
for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
$linea = togli_acapo($file_giornata[$num1]);
if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
if ($leggendo_formazioni == "SI") {
if ($linea == "#@& formazione #@&") $giocatore = "";
if ($giocatore) {
${$formazione}[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($giocatore)
if ($aggiorna_giocatore) {
$giocatore = $linea;
$formazione = "formazione_$giocatore";
$num2 = 0;
$aggiorna_giocatore = "";
} # fine if ($aggiorna_giocatore)
if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
} # fine if ($leggendo_formazioni == "SI")

if ($linea == "#@& fine voti #@&") $leggendo_voti = "NO";
if ($leggendo_voti == "SI") {
$voti[$num2] = $linea;
$num2++;
} # fine if ($leggendo_voti == "SI")
if ($linea == "#@& voti #@&") {
$leggendo_voti = "SI";
$voti_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& voti #@&")

if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi[$num2] = $linea;
$num2++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& punteggi #@&")

if ($linea == "#@& fine scontri #@&") $leggendo_scontri = "NO";
if ($leggendo_scontri == "SI") {
$scontri[$num2] = $linea;
$num2++;
} # fine if ($leggendo_scontri == "SI")
if ($linea == "#@& scontri #@&") {
$leggendo_scontri = "SI";
$scontri_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& scontri #@&")
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$nome_posizione[$num1] = $giocatore;

$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
if ($soprannome_squadra[3]) {
$nome_sqadra_memo[$giocatore] = $soprannome_squadra[3];
$soprannome_squadra = "<b>".$soprannome_squadra[3]."</b>";
} # fine if ($soprannome_squadra[3])
else {
$soprannome_squadra = "Squadra";
$nome_sqadra_memo[$giocatore] = $giocatore;
} # fine else if ($soprannome_squadra[3])

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>$soprannome_squadra di $giocatore<br><br>";
$formazione = "formazione_$giocatore";
$formazione = $$formazione;
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";


$tipo_campionato = "";
$num_giornata = str_replace("giornata","",$giornata);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_campionato = $giornate_campionato[0];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";

if ($tipo_campionato == "S") {
echo "<br><table align=\"center\" border=\"1\">";
# <tr><td colspan=2>Partite:</td></tr>";
$partite = "";
$marcotori = "";
$num_scontri = count($scontri);
for ($num1 = 0 ; $num1 < $num_scontri ; $num1++) {
$dati_scontri = explode("##@@&&", $scontri[$num1]);
echo "<tr><td>".$nome_sqadra_memo[$dati_scontri[0]]."-".$nome_sqadra_memo[$dati_scontri[1]]."</td>
<td>".$dati_scontri[2]."-".$dati_scontri[3]."</td></tr>";
} # fine for $num1
echo "</table><br>";
} # fine if ($tipo_campionato == "S")


echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";


if ($voti_esistenti == "SI") {

echo "<br><table align=\"center\"><tr><td>Voti_della_$giornata:<br>";
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voti = explode("##@@&&", $voti[$num1]);
settype($dati_voti[1],"double");
$voto[$dati_voti[0]] = $dati_voti[1];
} # fine for $num1
arsort ($voto);
reset ($voto);
while (list ($key, $val) = each ($voto)) {
echo $nome_sqadra_memo[$key].": $val<br>";
} # fine while
echo "</td>";

if ($tipo_campionato == "P") {
echo "<td>Punti:<br>";
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggi = explode("##@@&&", $punteggi[$num1]);
settype($dati_punteggi[1],"double");
$punteggio[$dati_punteggi[0]] = $dati_punteggi[1];
} # fine for $num1
arsort ($punteggio);
reset ($punteggio);
while (list ($key, $val) = each ($punteggio)) {
echo "$val<br>";
} # fine while
echo "</td>";
} # fine if ($tipo_campionato == "P")

# calcolo la classifica fino a questa giornata
if ($tipo_campionato != "N") {
$punti = "";
for ($num1 = $g_inizio_campionato ; $num1 <= $num_giornata ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_punti = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata_punti")) {
$file_giornata_p = @file("$percorso_cartella_dati/$giornata_punti");
$num_linee_file_giornata_p = count($file_giornata_p);
$leggendo_punteggi = "NO";
$punteggi_esistenti_p = "NO";
for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
$linea = togli_acapo($file_giornata_p[$num2]);
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi_p[$num3] = $file_giornata_p[$num2];
$num3++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti_p = "SI";
$num3 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1
if ($punteggi_esistenti_p == "SI") {
$num_punteggi_p = count($punteggi_p);
for ($num2 = 0 ; $num2 < $num_punteggi_p ; $num2++) {
$dati_punteggio = explode("##@@&&", $punteggi_p[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if ($punteggi_esistenti_p == "SI")
} # fine if (@is_file("$percorso_cartella_dati/$giornata_punti"))
} # fine for $num1

echo "<td>&nbsp;&nbsp;</td><td><font color=\"red\">Classifica_alla_giornata_$num_giornata_campionato:</font><br>";
arsort ($punti);
reset ($punti);
while (list ($key, $val) = each ($punti)) {
echo $nome_sqadra_memo[$key].": $val<br>";
} # fine while
echo "</td>";
} # fine if ($tipo_campionato != "N")
echo "</tr></table>";
echo "<br><center>Giornata chiusa.</center><br>";
} # fine if ($voti_esistenti == "SI")

if ($target) $target = " target=\"$target\"";
if (!$origine) $origine = "mercato.php";
echo "<center><form method=\"post\" action=\"$origine\"$target>
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";



include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/guarda_giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


$parla = "NO";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");


for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_controlla = "giornata$num1";
if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
else $giornata_ultima = $num1;
} # fine for $num1

$num_giornata_richiesta = substr($giornata,-2);
if (!$giornata or $num_giornata_richiesta > $giornata_ultima) $giornata = "giornata$giornata_ultima";

echo "<table width=\"100%\" align=\"center\"><tr><td width=\"33%\" align=\"left\">
<form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 <= $giornata_ultima ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine for $num1
echo "</select></form></td>";

$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";
$voti = "";
$scontri = "";
$data = "";
$num2 = 0;
$leggendo_formazioni = "SI";
$leggendo_punteggi = "NO";
$leggendo_voti = "NO";
$leggendo_scontri = "NO";
$voti_esistenti = "NO";

if ($giornata_ultima) $file_giornata = file("$percorso_cartella_dati/$giornata");
$num_linee_file_giornata = count($file_giornata);
for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
$linea = togli_acapo($file_giornata[$num1]);
if (substr($linea,0,12) == "#@& data #@&") $data = substr($linea,12);

if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
if ($leggendo_formazioni == "SI") {
if ($linea == "#@& formazione #@&") $giocatore = "";
if ($giocatore) {
${$formazione}[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($giocatore)
if ($aggiorna_giocatore) {
$giocatore = $linea;
$formazione = "formazione_$giocatore";
$num2 = 0;
$aggiorna_giocatore = "";
} # fine if ($aggiorna_giocatore)
if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
} # fine if ($leggendo_formazioni == "SI")

if ($linea == "#@& fine voti #@&") $leggendo_voti = "NO";
if ($leggendo_voti == "SI") {
$voti[$num2] = $linea;
$num2++;
} # fine if ($leggendo_voti == "SI")
if ($linea == "#@& voti #@&") {
$leggendo_voti = "SI";
$voti_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& voti #@&")

if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi[$num2] = $linea;
$num2++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& punteggi #@&")

if ($linea == "#@& fine scontri #@&") $leggendo_scontri = "NO";
if ($leggendo_scontri == "SI") {
$scontri[$num2] = $linea;
$num2++;
} # fine if ($leggendo_scontri == "SI")
if ($linea == "#@& scontri #@&") {
$leggendo_scontri = "SI";
$scontri_esistenti = "SI";
$num2 = 0;
} # fine if ($linea == "#@& scontri #@&")
} # fine for $num1



echo "<td align=\"center\"><b>$giornata</b><br><font size=\"-2\">$data</font></td>
<td width=\"33%\" align=\"right\">
<table><tr><td>
<form method=\"post\" action=\"stat_campionato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Statistiche\">
</form></td><td>
<form method=\"post\" action=\"calendario.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Calendario\">
</form></td></tr></table></td></tr></table>";



$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$nome_posizione[$num1] = $giocatore;

$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
if ($soprannome_squadra[3]) {
$nome_sqadra_memo[$giocatore] = $soprannome_squadra[3];
$soprannome_squadra = "<b>".$soprannome_squadra[3]."</b>";
} # fine if ($soprannome_squadra[3])
else {
$soprannome_squadra = "Squadra";
$nome_sqadra_memo[$giocatore] = $giocatore;
} # fine else if ($soprannome_squadra[3])

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>$soprannome_squadra di $giocatore<br><br>";
$formazione = "formazione_$giocatore";
$formazione = $$formazione;
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";


$tipo_campionato = "";
$num_giornata = str_replace("giornata","",$giornata);
if (substr($num_giornata,0,1) == 0) $num_giornata = substr($num_giornata,1);
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
if ($num_giornata <= $giornate_campionato[1] and $num_giornata >= $giornate_campionato[0]) {
$num_giornata_campionato = $num_giornata - $giornate_campionato[0] + 1;
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_campionato = $giornate_campionato[0];
break;
} # fine if ($num_giornata <= $giornate_campionato[1] and...
next($campionato);
} # fine for $num1
if (!$tipo_campionato) $tipo_campionato = "N";

if ($tipo_campionato == "S") {
echo "<br><table align=\"center\" border=\"1\">";
# <tr><td colspan=2>Partite:</td></tr>";
$partite = "";
$marcotori = "";
$num_scontri = count($scontri);
for ($num1 = 0 ; $num1 < $num_scontri ; $num1++) {
$dati_scontri = explode("##@@&&", $scontri[$num1]);
echo "<tr><td>".$nome_sqadra_memo[$dati_scontri[0]]."-".$nome_sqadra_memo[$dati_scontri[1]]."</td>
<td>".$dati_scontri[2]."-".$dati_scontri[3]."</td></tr>";
} # fine for $num1
echo "</table><br>";
} # fine if ($tipo_campionato == "S")


echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";


if ($voti_esistenti == "SI") {

echo "<br><table align=\"center\"><tr><td>Voti_della_$giornata:<br>";
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voti = explode("##@@&&", $voti[$num1]);
settype($dati_voti[1],"double");
$voto[$dati_voti[0]] = $dati_voti[1];
} # fine for $num1
arsort ($voto);
reset ($voto);
while (list ($key, $val) = each ($voto)) {
echo $nome_sqadra_memo[$key].": $val<br>";
} # fine while
echo "</td>";

if ($tipo_campionato == "P") {
echo "<td>Punti:<br>";
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggi = explode("##@@&&", $punteggi[$num1]);
settype($dati_punteggi[1],"double");
$punteggio[$dati_punteggi[0]] = $dati_punteggi[1];
} # fine for $num1
arsort ($punteggio);
reset ($punteggio);
while (list ($key, $val) = each ($punteggio)) {
echo "$val<br>";
} # fine while
echo "</td>";
} # fine if ($tipo_campionato == "P")

# calcolo la classifica fino a questa giornata
if ($tipo_campionato != "N") {
$punti = "";
for ($num1 = $g_inizio_campionato ; $num1 <= $num_giornata ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_punti = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata_punti")) {
$file_giornata_p = @file("$percorso_cartella_dati/$giornata_punti");
$num_linee_file_giornata_p = count($file_giornata_p);
$leggendo_punteggi = "NO";
$punteggi_esistenti_p = "NO";
for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
$linea = togli_acapo($file_giornata_p[$num2]);
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi_p[$num3] = $file_giornata_p[$num2];
$num3++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti_p = "SI";
$num3 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1
if ($punteggi_esistenti_p == "SI") {
$num_punteggi_p = count($punteggi_p);
for ($num2 = 0 ; $num2 < $num_punteggi_p ; $num2++) {
$dati_punteggio = explode("##@@&&", $punteggi_p[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if ($punteggi_esistenti_p == "SI")
} # fine if (@is_file("$percorso_cartella_dati/$giornata_punti"))
} # fine for $num1

echo "<td>&nbsp;&nbsp;</td><td><font color=\"red\">Classifica_alla_giornata_$num_giornata_campionato:</font><br>";
arsort ($punti);
reset ($punti);
while (list ($key, $val) = each ($punti)) {
echo $nome_sqadra_memo[$key].": $val<br>";
} # fine while
echo "</td>";
} # fine if ($tipo_campionato != "N")
echo "</tr></table>";
echo "<br><center>Giornata chiusa.</center><br>";
} # fine if ($voti_esistenti == "SI")

if ($target) $target = " target=\"$target\"";
if (!$origine) $origine = "mercato.php";
echo "<center><form method=\"post\" action=\"$origine\"$target>
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";



include("$percorso_cartella_dati/foot.php");
?>
